summaryrefslogtreecommitdiffstats
path: root/examples/pyKHTMLPart.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/pyKHTMLPart.py')
-rw-r--r--examples/pyKHTMLPart.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/examples/pyKHTMLPart.py b/examples/pyKHTMLPart.py
index 7873ad8..6d92c1c 100644
--- a/examples/pyKHTMLPart.py
+++ b/examples/pyKHTMLPart.py
@@ -43,7 +43,7 @@ lifted from the KDE classref.
# If you import more classes, don't forget to add them here (some of these
# are extras/not used)
-from tdecore import KCmdLineArgs, KURL, KApplication, i18n, KAboutData, BarIcon, KLibLoader
+from tdecore import KCmdLineArgs, KURL, TDEApplication, i18n, KAboutData, BarIcon, KLibLoader
from tdeui import KMainWindow, KMessageBox, KAction, KStdAction, KKeyDialog, KEditToolbar
@@ -192,10 +192,10 @@ aboutData = KAboutData ("pyKHTMLPart", "pyHTMLPart",\
aboutData.addAuthor ("Jim Bublitz", "Example for PyKDE", "[email protected]")
# This MUST go here (before KApplication () is called)
KCmdLineArgs.init (sys.argv, aboutData)
-app = KApplication ()
+app = TDEApplication ()
if (app.isRestored()):
RESTORE(KLess)
@@ -192,10 +192,10 @@ aboutData = KAboutData ("pyKHTMLPart", "pyHTMLPart",\
aboutData.addAuthor ("Jim Bublitz", "Example for PyKDE", "[email protected]")
-# This MUST go here (before KApplication () is called)
+# This MUST go here (before TDEApplication () is called)
KCmdLineArgs.init (sys.argv, aboutData)